==> Paws-0.31.tar.gz: Paws-0.31/lib/Paws/IAM/DeleteSAMLProvider.pm <==

package Paws::IAM::DeleteSAMLProvider;
  use Moose;
  has SAMLProviderArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteSAMLProvider');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::DeleteSAMLProvider - Arguments for method DeleteSAMLProvider on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteSAMLProvider on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method DeleteSAMLProvider.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteSAMLProvider.

As an example:

  $service_obj->DeleteSAMLProvider(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> SAMLProviderArn => Str

The Amazon Resource Name (ARN) of the SAML provider to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteSAMLProvider in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/IAM/DeleteSAMLProvider.pm <==

package Paws::IAM::DeleteSAMLProvider;
  use Moose;
  has SAMLProviderArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteSAMLProvider');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::DeleteSAMLProvider - Arguments for method DeleteSAMLProvider on L<Paws::IAM>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteSAMLProvider on the
L<AWS Identity and Access Management|Paws::IAM> service. Use the attributes of this class
as arguments to method DeleteSAMLProvider.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteSAMLProvider.

=head1 SYNOPSIS

    my $iam = Paws->service('IAM');
    $iam->DeleteSAMLProvider(
      SAMLProviderArn => 'MyarnType',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iam/DeleteSAMLProvider>

=head1 ATTRIBUTES


=head2 B<REQUIRED> SAMLProviderArn => Str

The Amazon Resource Name (ARN) of the SAML provider to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteSAMLProvider in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
